bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDMoments.compute_fixed_moments
==================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaARDMoments.compute_fixed_moments